pub struct UnresolvedMonitor {
pub statement: MonitorStatement,
pub reason: UnresolvedMonitorReason,
}Expand description
One statement that named nothing, kept with the reason.
Fields
statement: MonitorStatementreason: UnresolvedMonitorReasonTrait Implementations
Sourceimpl Clone for UnresolvedMonitor
impl Clone for UnresolvedMonitor
Sourcefn clone(&self) -> UnresolvedMonitor
fn clone(&self) -> UnresolvedMonitor
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for UnresolvedMonitor
impl Debug for UnresolvedMonitor
Sourceimpl PartialEq for UnresolvedMonitor
impl PartialEq for UnresolvedMonitor
Sourcefn eq(&self, other: &UnresolvedMonitor) -> bool
fn eq(&self, other: &UnresolvedMonitor) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for UnresolvedMonitor